@@ -1,5 +1,4 @@
 /*
- * "$Id: bit-ops.h,v 1.4 2009/05/17 19:25:36 rlk Exp $"
  *
  *   Softweave calculator for gimp-print.
  *
@@ -16,8 +15,7 @@
  *   for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *   along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /**
@@ -76,6 +74,17 @@ extern void	stp_fold_3bit_323(const unsigned char *line, int single_length,
 extern void	stp_fold_4bit(const unsigned char *line, int single_length,
 			 unsigned char *outbuf);
 
+/**
+ * Interleave a buffer consisting of eight bit strings of length single_length
+ * into one string of packed eight-bit ints.
+ *
+ * @param line the input bit string
+ * @param single_length the length (in bytes) of the input
+ * @param outbuf the output.
+ */
+extern void	stp_fold_8bit(const unsigned char *line, int single_length,
+			 unsigned char *outbuf);
+
 /**
  * Split an input sequence of packed 1 or 2 bit integers into two or more
  * outputs of equal length, distributing non-zero integers round robin
@@ -117,7 +126,7 @@ extern void	stp_split_4(int height, int bits, const unsigned char *in,
  * @param n the number of outputs into which the input should be distributed
  * @param in the input bit string
  * @param outs the array of output bit strings
- * 
+ *
  */
 extern void	stp_unpack(int height, int bits, int n, const unsigned char *in,
 			   unsigned char **outs);
